package hw5;

import java.io.PrintStream;
import java.util.Properties;

/**
 * @author Michael Schwartz, 
 * 
 * The superclass for FormLetters. An FormLetterTemplate object contains all of
 * the data associated with a particular FormLetter story.
 * 
 * Implementations will have to worry about how to store the various entries
 * and manage their order
 * 
 **/
public abstract class FormLetterTemplate {

	private String title;

	/**
	 * 
	 * Create a new FormLetterTemplate with the given title. Note that there is
	 * no default constructor.
	 * 
	 **/
	public FormLetterTemplate(String title) {
		this.title = title;
	}

	/**
	 * 
	 * Get the title of this FormLetter.
	 * 
	 **/
	public String getTitle() {
		return this.title;
	}

	/**
	 * 
	 * Add a text entry to the template with the given text
	 * 
	 **/
	abstract public void addTextEntry(String text);

	/**
	 * 
	 * Add a data item for substitution to the template with the 
	 * given dataName
	 * 
	 **/
	abstract public void addDataItemEntry(String dataName);

	/**
	 *
	 * Print out the FormLetter as a template to the output stream provided
	 *
	 * This is for debugging (or storage) purposes; 
	 * print out the FormLetter with the DataEntries
	 * names substituted instead of the replaced values. 
	 * For example, a FormLetter containing the TextEntry "Hi," 
	 * followed by a DataEntry with type name
	 * "name" would print out "Hi, <name>".
	 *
	 **/
	abstract public void printFormLetterTemplate(PrintStream out);

	/**
	 *
	 * Gather the information for the form letter and 
	 * generate the result to the output stream provided.
	 *
	 **/
	abstract public void doFormLetter(Properties data, PrintStream out);
}
